@@ -25,8 +25,9 @@ from calculate.install.distr import Distributive
 from calculate.lib.cl_lang import (setLocalTranslate, getLazyLocalTranslate)
 import time
 from calculate.lib.configparser import ConfigParser
-from calculate.lib.utils.files import (readFile, listDirectory, isMount,
+from calculate.lib.utils.files import (readFile, listDirectory,
                                        writeFile)
+from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.git import Git
 from .datavars import BuilderError
 from calculate.lib.utils.tools import Locker, LockError
@@ -145,7 +146,7 @@ class BuildStorage(object):
     """
     Хранилище в котором находится информация о собираемом дистрибутиве
     """
-    ini_file = "/etc/calculate/builder.env"
+    ini_file = "/var/lib/calculate/calculate-builder/builder.env"
     data_dir = path.join(builder_data, "mount")
 
     def __init__(self, data_dir=None, ini_file=None):
@@ -155,7 +156,7 @@ class BuildStorage(object):
             self.data_dir = data_dir
         if not path.exists(self.data_dir):
             os.makedirs(self.data_dir)
-        self.locker = Locker(fn=self.ini_file)
+        self.locker = Locker(path.basename(self.ini_file))
 
     def _get_ini(self):
         ini = ConfigParser()
@@ -167,7 +168,7 @@ class BuildStorage(object):
             with self.locker:
                 return self._get_ini()
         except LockError:
-            raise BuilderError("Failed to lock assemble.env")
+            raise BuilderError("Failed to lock builder.env")
 
     def reserve_id(self, build_id):
         """
@@ -185,8 +186,11 @@ class BuildStorage(object):
             with self.locker:
                 ini = self._get_ini()
                 yield ini
-                with open(self.ini_file, 'w') as f:
-                    ini.write(f)
+                if not ini.sections() and path.exists(self.ini_file):
+                    os.unlink(self.ini_file)
+                else:
+                    with open(self.ini_file, 'w') as f:
+                        ini.write(f)
         except LockError:
             raise BuilderError("Failed to lock assemble.env")
 
