@@ -76,6 +76,9 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     env.VariableClEnvData(),
                     env.VariableClEnvPath(),
                     env.VariableClEbuildPhase(),
+                    update.VariableClUpdateReposStorage(section="update"),
+                    update.VariableClUpdateReposconf(section="update"),
+                    update.VariableClUpdateReposconfDir(section="update"),
                     update.VariableClUpdateUsetagSet(section="update"),
                     update.VariableClUpdateGpgForce(section="update"),
                     update.VariableClUpdateGpgKeys(section="update"),
@@ -90,8 +93,6 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     update.VariableClUpdateRepRev(section="update"),
                     update.VariableClUpdateBranch(section="update"),
                     update.VariableClUpdateBranchName(section="update"),
-                    update.VariableClUpdateLaymanConfig(section="update"),
-                    update.VariableClUpdateLaymanStorage(section="update"),
                     update.VariableClProfileRepository(section="update"),
                     update.VariableClUpdateBinhost(section="update"),
                     update.VariableClUpdateBinhostData(section="update"),
